Skip to main contentCrate haalka_futures_signals_ext
Source pub use futures_signals;
- futures_util
- Combinators and utilities for working with
Futures, Streams, Sinks,
and the AsyncRead and AsyncWrite traits. - signal
- stream_ext_ext
- map_mut
map_mut is exactly the same as map_ref, except it gives
mutable references (map_ref gives immutable references).- map_ref
- The
map_ref macro can be used to combine multiple Signals together: - match_to_option
- match_to_signal_cloned_option
- match_to_signal_vec_cloned
- Broadcaster
- Splits an input
Signal into multiple output Signals. - Mutable
- MutableBTreeMap
- MutableSignal
- MutableSignalMap
- MutableSignalVec
- MutableVec
- MutableVecLockMut
- ReadOnlyMutable
- Receiver
- Sender
- SignalStream
- MapDiff
- SignalEither
- VecDiff
- Future
- A future represents an asynchronous computation, commonly obtained by use of
async. - FutureExt
- An extension trait for
Futures that provides a variety of convenient
adapters. - MapDiffExt
- MutableBTreeMapExt
- MutableExt
- MutableExtOption
- MutableVecExt
- ReadOnlyMutableExt
- ReadOnlyMutableExtOption
- Signal
- SignalExt
- SignalExtBool
- SignalExtExt
- SignalExtOption
- SignalMap
- SignalMapExt
- SignalMapExtExt
- SignalVec
- SignalVecExt
- Sink
- A
Sink is a value into which other values can be sent, asynchronously. - SinkExt
- An extension trait for
Sinks that provides a variety of convenient
combinator functions. - Stream
- A stream of values produced asynchronously.
- StreamExt
- An extension trait for
Streams that provides a variety of convenient
combinator functions. - StreamExtExt
- always
- always_map
- Converts an
IntoIterator<Item = (K, V)> into a SignalMap<Key = K, Value = V>. - always_vec
- Converts a
Vec<A> into a SignalVec<Item = A> - channel
- BoxSignal
- An owned dynamically typed
Signal. - BoxSignalMap
- An owned dynamically typed
SignalMap. - BoxSignalVec
- An owned dynamically typed
SignalVec. - LocalBoxSignal
- Same as
BoxSignal, but without the Send requirement. - LocalBoxSignalMap
- Same as
BoxSignalMap, but without the Send requirement. - LocalBoxSignalVec
- Same as
BoxSignalVec, but without the Send requirement.